#!/bin/dash
################################################################################
# Copyright (c) 2024 Jersey Jack Pinball
################################################################################
# process command line options
################################################################################
# put a : in the beginning of the option string to suppress getopts error
# message. follow an option with a : to make getopts require an argument.
# it can be accessed in the variable OPTARG.
while getopts ":u?" opt; do
  case $opt in
    u ) put_on_usb_stick='true' ;;
   \? ) show_usage
        exit 1 ;;
  esac
done
# this shift puts the remaining command arguments into variables $1, 2$, 3$...
shift $(($OPTIND - 1))

################################################################################
# main code
################################################################################
ts=$(date +"%Y%m%d-%H%M%S")
game=${GAMENAME:+-$GAMENAME}
usb_folder='/mnt/usb'
tmp_root='/tmp'
logdump_dirname='logdump'
tmp_folder="${tmp_root}/${logdump_dirname}"

# clean up any previous dump
rm -rf "$tmp_folder" > /dev/null 2>&1
mkdir -p "$tmp_folder"

# grab a bunch of info
export DISPLAY=:0
xrandr > "$tmp_folder"/xrandroutput.txt
cp /var/log/kern.log* "$tmp_folder"
cp /var/log/syslog* "$tmp_folder"
cp /var/log/Xorg* "$tmp_folder"
cp /var/log/dmesg* "$tmp_folder"
cp /jjpe/temp/*.log* "$tmp_folder"
cp /jjpe/temp/*progress "$tmp_folder" 2> /dev/null
cp /jjpe/temp/curl* "$tmp_folder" 2> /dev/null
cp /tmp/hwinfo "$tmp_folder"
cp -r /tmp/pinballstats "$tmp_folder"
cp /jjpe/gen1/setenv.sh "$tmp_folder"
cp /jjpe/gen1/setup_displays.sh "$tmp_folder" 2> /dev/null
cp /jjpe/gen1/setupdisplays.sh "$tmp_folder" 2> /dev/null
cp /etc/timezone "$tmp_folder"
mount > "$tmp_folder"/mount_output.txt
df -h > "$tmp_folder"/df_output.txt
lsusb > "$tmp_folder"/lsusb_output.txt
lsusb -vv > "$tmp_folder"/lsusb_output_verbose.txt 2> /dev/null
journalctl -o short-precise > "$tmp_folder"/systemdlog.txt
amixer > "$tmp_folder"/amixeroutput.txt
pactl list > "$tmp_folder"/pactl_list_output.txt
pactl list cards > "$tmp_folder"/pactl_card_output.txt
ip -d a > "$tmp_folder"/ip_a_output.txt
# grab a copy of game settings, audits, trace files, etc.
cp -r /jjpe/perm/vf/ "$tmp_folder"
# omit any photos
rm -rf "$tmp_folder"/vf/misc/photos

if [ $put_on_usb_stick ]; then
  # zip it all up and put on USB stick
  cd "$tmp_root"
  zip -r "${usb_folder}/logdump${game}-${ts}.zip" "$logdump_dirname"
  umount /mnt/usb
fi
