#!/bin/dash

################################################################################
# globals
################################################################################
export JJPEDIR='/jjpe/gen1'
export DISPLAY=':0'

################################################################################
# locals
################################################################################
jimage=$JJPEDIR/scripts/jimg
graphics=$JJPEDIR/miscfiles/graphics
logfile=/jjpe/temp/game.log

################################################################################
# redirect stdout/stderr to log file
################################################################################
exec >> $logfile 2>&1

################################################################################
# game setup
################################################################################
# read in the game-specific environment variable(s).
. $JJPEDIR/setenv.sh
export GAMEDIR=$JJPEDIR/$GAMENAME

# do the power on/init stuff
chmod +x $JJPEDIR/scripts/runonce.sh
$JJPEDIR/scripts/runonce.sh

################################################################################
# main game loop
################################################################################
while true
do
  # run the game and process its exit code
  $GAMEDIR/game
  result="$?"
  case "$result" in
     1) # dongle missing
        $jimage 5000 $graphics/JJP_logo_message.png \
			"$GAMENAME SECURITY KEY MISSING" "Insert purple USB key. Game will rescan in a moment."
        ;;
    42) # net img or delta update
        reboot
        sleep 99 ;;
    43) # settings restore - need to restart the game
        ;;
    44) # changed setting - required a restart
        ;;
    68) # maintenance reboot (hostname set)
        reboot
        sleep 99 ;;
    69) # maintenance reboot
        $jimage 5000 $graphics/JJP_logo_message.png \
            "MAINTENANCE REBOOT" "Please wait ..."
        reboot
        sleep 99 ;;
   127) # executable not found
        if [ -d $JJPEDIR/JJPECore ]
        then
            # on a dev disk, explain what's going on
            $jimage 5000 $graphics/JJP_logo_message.png \
                "$GAMEDIR/game not found"
        else
            # on a release image, give a hint on how to fix problem
            $jimage 5000 $graphics/JJP_logo_message.png \
                "GAME EXECUTION ERROR" "Reinstall game."
        fi
        ;;
   254) # pressed escape
        ;;
     *) # unexpected exit
        if [ -d $JJPEDIR/JJPECore ]
        then
            # on a dev disk, show the abnormal exit
            err=$(tail -5 "$logfile" | grep "ID:")
            $jimage 5000 $graphics/JJP_logo_message.png \
                "$GAMENAME EXITED ABNORMALLY" "$err"
        fi
        ;;
  esac
done
