#!/bin/dash
# Environment variables used:
#   JJPEDIR = location of JJPE stuff (e.g., "/jjpe/gen1")
#   GAMEDIR = location of game stuff (e.g., "WizardOfOz")
if [ -z "$JJPEDIR" ] || [ -z "$GAMEDIR" ]
then
	printf "Environment variable(s) not set.  Check JJPEDIR, GAMEDIR\n"
	exit -1
fi

# workaround: fix up problem with non-executable jjpe-mount-generator
mountgen='/etc/systemd/system-generators/jjpe-mount-generator'
if [ -e "$mountgen" ] && [ ! -x "$mountgen" ] && ! (mount | grep -q '/jjpe/perm')
then
	chmod 755 "$mountgen"
	reboot
fi

# ensure that the vf directory on the perm partition and symbolic link exist
mkdir -p /jjpe/perm/vf
ln -s -f -T /jjpe/perm/vf $GAMEDIR/vf

# cleanup any leftover stuff from a prior SW update
rm -f /jjpe/temp/rprogress
rm -f /jjpe/temp/pcprogress

# the following line turns off all screensaver stuff.
xset -dpms s off s noblank s 0 0 s noexpose

# setup the bluetooth dongle
hciconfig hci0 up piscan > /dev/null 2>&1
bt_status=$?

# hide BT friendly name for games in development
if [ "$bt_status" = "0" ] && [ -e $JJPEDIR/JJPECore ]
then
	 bluetoothctl system-alias "Dev Game-$(grep -o '[0-9].*$' /etc/hostname)"
fi

# make sure the grub screen doesn't show on next boot
cd /boot/grub
rm grubenv
grub-editenv grubenv unset recordfail

# ensure proper ownership/permissions
chown -R root:root $GAMEDIR/*
chmod --silent +x $GAMEDIR/game
chmod --silent +x $JJPEDIR/*.sh
chmod --silent +x $JJPEDIR/*.pl
chmod --silent --recursive +x $JJPEDIR/scripts/

# do the display setup
display_script=$JJPEDIR/setupdisplays.sh
# try legacy script first
if ! $JJPEDIR/scripts/setdisplayconf.sh "$display_script"
then
	# not handled by legacy script; use new script
	$JJPEDIR/scripts/setdisplayconf.pl "$display_script"
fi
$display_script

# make PNGs of each page of the operator manual
OPMANPDF=$GAMEDIR/opmanual.pdf
if [ ! -e $OPMANPDF ]
then
	# look in old location
	OPMANPDF=$JJPEDIR/opmanual.pdf
fi
OPMANDIR=$JJPEDIR/ecoredata/graphics/operatormanual
if [ ! -d $OPMANDIR ]
then
	mkdir -p $OPMANDIR
fi

if [ -e $OPMANPDF ]
then
	lastpage_num=`gs -q -dNODISPLAY -dNOSAFER -c "($OPMANPDF) (r) file runpdfbegin pdfpagecount = quit"`
	pdf_md5=`md5sum $OPMANPDF | cut -d' ' -f 1`
	if [ ! -e $OPMANDIR/lastrendered ] \
		|| [ $pdf_md5 != "`cat $OPMANDIR/lastrendered`" ] \
		|| [ ! -e $OPMANDIR/manualpage$lastpage_num.png ]
	then
		rm $OPMANDIR/* > /dev/null 2>&1
		gs -dSAFER -dBATCH -dNOPAUSE -sDEVICE=png16m -dTextAlphaBits=4 -dGraphicsAlphaBits=4 -dFirstPage=1 -dLastPage=$lastpage_num -sOutputFile=$OPMANDIR/manualpage%d.png -r360 -dDownScaleFactor=2 -q $OPMANPDF -c quit &
		echo $pdf_md5 > $OPMANDIR/lastrendered
	fi
fi

#Make PNGs of each page of the terms and conditions
TANDCPDF=$JJPEDIR/miscfiles/eua/jjp_internet_terms_conditions_privacy_policy.pdf
TANDCDIR=$JJPEDIR/ecoredata/graphics/internet_tandc
if [ ! -d $TANDCDIR ]
then
	mkdir -p $TANDCDIR
fi

if [ -e $TANDCPDF ]
then
	pageNum=`gs -q -dNODISPLAY -dNOSAFER -c "($TANDCPDF) (r) file runpdfbegin pdfpagecount = quit"`
	pdf_md5=`md5sum $TANDCPDF | cut -d' ' -f 1`
	if [ ! -e $TANDCDIR/lastrendered ] \
		|| [ $pdf_md5 != "`cat $TANDCDIR/lastrendered`" ] \
		|| [ ! -e $TANDCDIR/tandcpage$pageNum.png ]
	then
		rm $TANDCDIR/* > /dev/null 2>&1
		gs -dSAFER -dBATCH -dNOPAUSE -sDEVICE=png16m -dTextAlphaBits=4 -dGraphicsAlphaBits=4 \
			-dFirstPage=1 -dLastPage=$pageNum -sOutputFile=$TANDCDIR/tandcpage%d.png -r360 \
			-dDownScaleFactor=2 -q $TANDCPDF -c quit &
		echo $pdf_md5 > $TANDCDIR/lastrendered
	fi
fi

#Make PNGs of each page of the beta agreement
BETAPDF=$JJPEDIR/miscfiles/eua/jjp_beta_agreement-v1.pdf
BETADIR=/jjpe/temp
if [ -e $BETAPDF ]
then
	pageNum=`gs -q -dNODISPLAY -dNOSAFER -c "($BETAPDF) (r) file runpdfbegin pdfpagecount = quit"`
	pdf_md5=`md5sum $BETAPDF | cut -d' ' -f 1`
	if [ ! -e $BETADIR/lastrendered ] \
		|| [ $pdf_md5 != "`cat $BETADIR/lastrendered`" ] \
		|| [ ! -e $BETADIR/betaagreementpage$pageNum.png ]
	then
		rm $BETADIR/betaagreementpage* > /dev/null 2>&1
		gs -dSAFER -dBATCH -dNOPAUSE -sDEVICE=png16m -dTextAlphaBits=4 -dGraphicsAlphaBits=4 -dFirstPage=1 -dLastPage=$pageNum -sOutputFile=$BETADIR/betaagreementpage%d.png -r360 -dDownScaleFactor=2 -q $BETAPDF -c quit &
		echo $pdf_md5 > $BETADIR/lastrendered
	fi
fi
